"""
DEPRECATED: The pygeai.proxy module has been moved to a standalone package.

This module is deprecated and will be removed in pygeai v1.0.0.

Please migrate to the new pygeai-proxy package:

    pip install pygeai-proxy

Update your imports:

    # Before (deprecated):
    from pygeai.proxy.clients import ProxyClient
    from pygeai.proxy.managers import ServerManager
    from pygeai.proxy.servers import MCPServer, A2AServer

    # After:
    from pygeai_proxy.clients import ProxyClient
    from pygeai_proxy.managers import ServerManager
    from pygeai_proxy.servers import MCPServer, A2AServer

For a complete migration guide, see:
https://github.com/globant/pygeai-proxy/blob/main/MIGRATION.md
"""

import warnings

warnings.warn(
    "The 'pygeai.proxy' module is deprecated and will be removed in pygeai v1.0.0. "
    "Please install 'pygeai-proxy' and update your imports to 'pygeai_proxy'. "
    "See https://github.com/globant/pygeai-proxy/blob/main/MIGRATION.md for details.",
    DeprecationWarning,
    stacklevel=2
)
